capture log close
log using vf09noaw.log, replace                       
clear
set memory 1300m
set matsize 5225

**********************************************************************************************
*				RE-DO WITHOUT ENSEMBLE # WEIGHTING
**********************************************************************************************


**********************************************************************************************
*				LT ANALYSES
**********************************************************************************************


********************************************************************************************************************
*			
*				PANEL TESTS
*			
********************************************************************************************************************

*		Prepare analytic weights
use "lt.dta"
sum

matrix wp1=(1,5,1,1,1,1,1,1,2,6,5,3,1,1)		// make 2 halves of matrix due to space limits
matrix wp2=(1,1,3,5,4,7,4,1,1,1,1,1,1)		
	matrix ww1=wp1						// will need duplicates (first rows of matrices)
	matrix ww2=wp2

	forvalues j=2/372 {	
		matrix ww1=ww1\wp1				// left half of aw matrix (372x14)
		matrix ww2=ww2\wp2				// right half of aw matrix (372x13)
		}

	matrix aww1=vec(ww1)					// stack columns into vector (5208x1)
	matrix aww2=vec(ww2)					// stack columns into vector (4836x1)

	svmat aww1, names(aw1)				// convert vector aww1 to variable aw1
	svmat aww2, names(aw2)				// convert vector aww2 to variable aw2
	stack aw1 aw2, into(aw) wide
		keep aw
	save awvector.dta, replace
	sum
	clear

* 	make dummies and trends

*	obs dummy
use "lt.dta"
	generate one=1
		forvalues i=1/27 {
			generate zero`i'=0
			}
	stack zero1-zero23 one one one one ,into(obs) wide		// make 'obs' dummy variable for observations
	save obsdummy.dta, replace
	sum
	clear

*	bal dummy
use "lt.dta"
	generate one=1
		forvalues i=1/27 {
			generate zero`i'=0
			}
	stack zero1-zero25 one one ,into(bal) wide			// make 'bal' dummy variable for balloon data
	save baldummy.dta, replace
	sum
	clear

*	rss dummy
use "lt.dta"
	generate one=1
		forvalues i=1/24 {
			generate zero`i'=0
			}
	stack zero1-zero24 one zero1 zero1 ,into(rss) wide	// make 'rss' dummy variable for rss data
	save rdummy.dta, replace
	sum
	clear

*	time stack and group count
use "lt.dta"
		forvalues i=1/27 {
			generate t`i'=_n
			}
	stack t1-t27,into(time) wide						// make 'time' time stack
	generate count=_stack
	save timecount.dta, replace
	sum
	clear

*	data stack
use "lt.dta"
	stack mlt1-mlt23 ltuah ltrss lthad ltrich ,into(ltlong) wide	// make 'ltlong' data stack
	sum
	save ltlong.dta, replace


*	now read back in and do panel tests

use "ltlong.dta"
	merge using obsdummy
	drop _merge
	save long.dta, replace
	clear

use baldummy.dta
	merge using long.dta
	drop _merge
	save long.dta, replace
	clear

use awvector.dta
	merge using long.dta
	drop _merge
	save long.dta, replace
	clear

use rdummy.dta
	merge using long.dta
	drop _merge
	save long.dta, replace
	clear

use timecount.dta
	merge using long.dta
	drop _merge
	keep ltlong obs bal rss time count aw
	sum


generate obst=obs*time
generate balt=bal*time
generate rsst=rss*time

generate time2=time^2
generate obst2=obs*time2

generate post99=time>252
generate tpost99=time*post99
generate obst99=tpost99*obs
sum 

**************************************************************************************************************************
*
*				COMPARE TRENDS: WEIGHTED 
*
**************************************************************************************************************************

tsset count time 

xtpcse ltlong time obst obs , corr(psar1) p			
	lincom time+obst			// test if observed trend is significant

xtpcse ltlong time obst rsst obs rss if bal==0 , corr(psar1)  	
	lincom time+obst			// test if UAH trend is signif
	lincom time+obst+rsst		// test if RSS trend is signif
	lincom obst+rsst			// test if RSS trend differs from models
	test rss rsst			// test if RSS is a unique data set compared to UAH

xtpcse ltlong time obst balt obs bal , corr(psar1) 			
	lincom time+obst			// test if MSU trend is signif
	lincom time+obst+balt		// test if balloon trend is signif
	lincom obst+balt			// test if balloon trend differs from models
	test bal balt			// test if balloons are a unique data set compared to satellites


clear

**********************************************************************************************
*				DRAW GRAPHS
**********************************************************************************************
use "lt.dta"
generate t=_n

replace ltuah=ltuah/120
replace ltrss=ltrss/120
generate pcm=(mlt21)/120
generate mon = ym(year,month)
format mon %tm


hprescott8 ltrss, smooth(800) stub(hp)
hprescott8 ltuah, smooth(800) stub(hp)
hprescott8 pcm, smooth(800) stub(hp)

	rename hp_ltuah_t_1 hp_ltuah
	rename hp_ltrss_t_1 hp_ltrss
	rename hp_pcm_t_1 hp_pcm

line    	        hp_ltuah mon , xtitle("Year") ytitle("degrees C") clwidth(thin) 	clcolor(gs0) clpattern(dash)  ///
		|| line hp_ltrss mon , xtitle("Year") ytitle("degrees C") clwidth(thin) 	clcolor(gs0)  ///
		|| line hp_pcm mon , xtitle("Year") ytitle("degrees C") clwidth(thick) clcolor(gs5) ///
		   legend( pos(6) label(1 "UAH-lt") label(2 "RSS-lt") label(3 "PCM-lt") cols(3) ) 
graph save lt , replace
graph export lt.eps ,replace

replace ltuah=ltuah*120
replace ltrss=ltrss*120

**************************************************************************************************************************
*
*                     COMPARE TRENDS USING MULTIVARIATE METHOD OF VOGELSANG&FRANSES 2005
*				USE PANEL UP TO 2009
*
**************************************************************************************************************************


*	Get OLS beta and residual matrices
forvalues j=1/23 {
	regress mlt`j' t 
	predict r`j' , resid 
	matrix c=e(b)'
	matrix b`j'=c["t","y1"]
	matrix list b`j'
	}

regress ltuah t 
	predict r24 , resid 
	matrix c=e(b)'
	matrix b24=c["t","y1"]

regress ltrss t 
	predict r25 , resid
	matrix c=e(b)'
	matrix b25=c["t","y1"]

regress lthad t
	predict r26 , resid
	matrix c=e(b)'
	matrix b26=c["t","y1"]

regress ltrich t	
	predict r27 , resid
	matrix c=e(b)'
	matrix b27=c["t","y1"]

matrix b=[b1,b2,b3,b4,b5,b6,b7,b8,b9,b10,b11,b12,b13,b14,b15,b16,b17,b18,b19,b20,b21,b22,b23,b24,b25,b26,b27]'
matrix list b
sum

mkmat r1-r27, matrix(ut)
matrix dir
matrix u=ut'				// transpose residual matrix into 27x372


*			Make u vectors

forvalues j=1/372 {			// extract u1 - u252 vectors
	matrix u`j'=u[1..27,`j']
	}


*			Make S-hat matrices
matrix ss1=u1*u1'

forvalues j=2/372 {
	matrix cumu=u1-u1			// set cumu to zero vector

	forvalues i=1/`j' {
		matrix cumu=cumu+u`i'	// sum u1+ --- +uj
				}

	matrix ss`j'=cumu*cumu'
			}

*			Make Omega matrix
matrix omega=I(27)-I(27)			// start at zero

forvalues j=1/372 {
	matrix omega=omega+ss`j'
			}
	matrix omega=2*omega/(372*372)

matrix list omega

*				Make t-mean(t) and call ttilde, then take dot product
egen tmean=mean(t)
generate ttilde=t-tmean
sum ttilde

mkmat ttilde
matrix tterm=ttilde'*ttilde
matrix list tterm

sum


********************************************************************************************************************
*			
*			MAKE t AND F TESTS FOLLOWING t2* and F2* IN VOGELSANG AND FRANSES 2005
*			
********************************************************************************************************************

*	critical values: 95% one-sided t is 5.222; F is 41.53

forvalues j=1/27 {

	matrix R=I(27)-I(27)			// start by making R as a 27x27 matrix of zeros, then put 1 in (j,j) slot
	matrix R[`j',`j']=1			// will test slope of model 1 for reference. 

	matrix rt=R[`j',1..27]
	matrix tbot=cholesky((rt*omega*rt')*inv(tterm))

	matrix rb=rt*b

	matrix t`j'=rb*inv(tbot)

	matrix fbot=syminv(R*omega*R')

	matrix F`j'=tterm*(R*b)'*fbot*(R*b)
	display "t"`j' " = " t`j'[1,1] "    F"`j' " = " F`j'[1,1]

			}



*			Test Average Model Slope = Average Obs Slope
matrix R=I(26)-I(26)			// start by making R as a 26x26 matrix of zeros 
matrix R26=J(26,1,0)			// make 26x1-length vector of zeros
matrix R=R,R26				// append it to side of R, making R now 26x27

*			Generate weights to test if ensemble means=obs means
*matrix R1=(1,5,1,1,1,1,1,1,2,6,5,3,1,1,1,1,3,5,4,7,4,1,1)
matrix R1=(1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1)
matrix R1=(1/23)*R1
matrix R1R=(-0.25,-0.25,-0.25,-0.25)
matrix R1=R1,R1R				// R1 is now 1x27 vector of testing weights
matrix R=R1\R				// make it top row of R, now R is 27x27

*		Construct F stat
	matrix fbot=syminv(R*omega*R')
	matrix F=tterm*(R*b)'*fbot*(R*b)
	matrix list F



*			Test UAH Slope = RSS Slope

matrix R=I(26)-I(26)			// start by making R as a 27x27 matrix of zeros 
matrix R26=J(26,1,0)			// make 26x1-length vector of zeros
matrix R=R,R26				// append it to side of R, making R now 26x27

*			Generate test weights 
matrix R1=(0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,-1,0,0)	
matrix R=R1\R				// make it top row of R, now R is 27x27

*		Construct F stat
	matrix fbot=syminv(R*omega*R')
	matrix F=tterm*(R*b)'*fbot*(R*b)
	matrix list F


*			Test MSU Slope = balloon Slope

matrix R=I(26)-I(26)			// start by making R as a 27x27 matrix of zeros 
matrix R26=J(26,1,0)			// make 26x1-length vector of zeros
matrix R=R,R26				// append it to side of R, making R now 26x27

*			Generate test weights 
matrix R1=(0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,.5,.5,-.5,-.5)	
matrix R=R1\R				// make it top row of R, now R is 27x27

	matrix fbot=syminv(R*omega*R')

	matrix F=tterm*(R*b)'*fbot*(R*b)
	matrix list F


*			Test Joint Obs Slope Significance

matrix R=I(26)-I(26)			// start by making R as a 27x27 matrix of zeros 
matrix R26=J(26,1,0)			// make 26x1-length vector of zeros
matrix R=R,R26				// append it to side of R, making R now 26x27

*			Generate test weights 
matrix R1=(0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,.25,.25,.25,.25)	
matrix R=R1\R				// make it top row of R, now R is 27x27

	matrix fbot=syminv(R*omega*R')

	matrix F=tterm*(R*b)'*fbot*(R*b)
	matrix list F























**********************************************************************************************
*				MT ANALYSES
**********************************************************************************************
clear
use "mt.dta"
generate t=_n

sum

********************************************************************************************************************
*			
*				PANEL TESTS
*			
********************************************************************************************************************


		
*	data stack
	stack mmt1-mmt23 mtuah mtrss mthad mtrich ,into(mtlong) wide	// make 'mtlong' data stack
	save mtlong.dta, replace


*	now read back in and do panel tests

use "mtlong.dta"
	merge using obsdummy
	drop _merge
	save long.dta, replace
	clear

use baldummy.dta
	merge using long.dta
	drop _merge
	save long.dta, replace
	clear

use awvector.dta
	merge using long.dta
	drop _merge
	save long.dta, replace
	clear

use rdummy.dta
	merge using long.dta
	drop _merge
	save long.dta, replace
	clear

use timecount.dta
	merge using long.dta
	drop _merge
	keep mtlong obs bal rss time count aw

generate obst=obs*time
generate balt=bal*time
generate rsst=rss*time

generate time2=time^2
generate obst2=obs*time2

generate post99=time>252
generate tpost99=time*post99
generate obst99=tpost99*obs

sum 
**************************************************************************************************************************
*
*				COMPARE TRENDS: WEIGHTED 
*
**************************************************************************************************************************

tsset count time 

xtpcse mtlong time obst obs , corr(psar1) p				
	lincom time+obst			// test if observed trend is significant

xtpcse mtlong time obst rsst obs rss if bal==0 , corr(psar1)  	
	lincom time+obst			// test if UAH trend is signif
	lincom time+obst+rsst		// test if RSS trend is signif
	lincom obst+rsst			// test if RSS trend differs from models
	test rss rsst			// test if RSS is a unique data set compared to UAH

xtpcse mtlong time obst balt obs bal , corr(psar1) 			
	lincom time+obst			// test if MSU trend is signif
	lincom time+obst+balt		// test if balloon trend is signif
	lincom obst+balt			// test if balloon trend differs from models
	test bal balt			// test if balloons are a unique data set compared to satellites


**********************************************************************************************
*				DRAW GRAPHS
**********************************************************************************************
clear
use "mt.dta"
generate t=_n

replace mtuah=mtuah/120
replace mtrss=mtrss/120
generate pcm=(mmt21)/120
generate mon = ym(year,month)
format mon %tm


hprescott8 mtrss, smooth(800) stub(hp)
hprescott8 mtuah, smooth(800) stub(hp)
hprescott8 pcm, smooth(800) stub(hp)

	rename hp_mtuah_t_1 hp_mtuah
	rename hp_mtrss_t_1 hp_mtrss
	rename hp_pcm_t_1 hp_pcm

line    	        hp_mtuah mon , xtitle("Year") ytitle("degrees C") clwidth(thin) 	clcolor(gs0) clpattern(dash)  ///
		|| line hp_mtrss mon , xtitle("Year") ytitle("degrees C") clwidth(thin) 	clcolor(gs0)  ///
		|| line hp_pcm mon , xtitle("Year") ytitle("degrees C") clwidth(thick) clcolor(gs5) ///
		   legend( pos(6) label(1 "UAH-mt") label(2 "RSS-mt") label(3 "PCM-mt") cols(3) ) 
graph save mt , replace
graph export mt.eps ,replace

replace mtuah=mtuah*120
replace mtrss=mtrss*120

**************************************************************************************************************************
*
*                     COMPARE TRENDS USING MULTIVARIATE METHOD OF VOGELSANG&FRANSES 2005
*				USE PANEL UP TO 2009
*
**************************************************************************************************************************
clear
use "mt.dta"
generate t=_n


*	Get OLS beta and residual matrices
forvalues j=1/23 {
	regress mmt`j' t 
	predict r`j' , resid 
	matrix c=e(b)'
	matrix b`j'=c["t","y1"]
	matrix list b`j'
	}

regress mtuah t 
	predict r24 , resid 
	matrix c=e(b)'
	matrix b24=c["t","y1"]

regress mtrss t 
	predict r25 , resid
	matrix c=e(b)'
	matrix b25=c["t","y1"]

regress mthad t
	predict r26 , resid
	matrix c=e(b)'
	matrix b26=c["t","y1"]

regress mtrich t	
	predict r27 , resid
	matrix c=e(b)'
	matrix b27=c["t","y1"]

matrix b=[b1,b2,b3,b4,b5,b6,b7,b8,b9,b10,b11,b12,b13,b14,b15,b16,b17,b18,b19,b20,b21,b22,b23,b24,b25,b26,b27]'
matrix list b
sum

mkmat r1-r27, matrix(ut)
matrix dir
matrix u=ut'				// transpose residual matrix into 27x372


*			Make u vectors

forvalues j=1/372 {			// extract u1 - u252 vectors
	matrix u`j'=u[1..27,`j']
	}


*			Make S-hat matrices
matrix ss1=u1*u1'

forvalues j=2/372 {
	matrix cumu=u1-u1			// set cumu to zero vector

	forvalues i=1/`j' {
		matrix cumu=cumu+u`i'	// sum u1+ --- +uj
				}

	matrix ss`j'=cumu*cumu'
			}

*			Make Omega matrix
matrix omega=I(27)-I(27)			// start at zero

forvalues j=1/372 {
	matrix omega=omega+ss`j'
			}
	matrix omega=2*omega/(372*372)

matrix list omega

*				Make t-mean(t) and call ttilde, then take dot product
egen tmean=mean(t)
generate ttilde=t-tmean
sum ttilde

mkmat ttilde
matrix tterm=ttilde'*ttilde
matrix list tterm

sum


********************************************************************************************************************
*			
*			MAKE t AND F TESTS FOLLOWING t2* and F2* IN VOGELSANG AND FRANSES 2005
*			
********************************************************************************************************************

*	critical values: 95% one-sided t is 5.222; F is 41.53

forvalues j=1/27 {

	matrix R=I(27)-I(27)			// start by making R as a 27x27 matrix of zeros, then put 1 in (j,j) slot
	matrix R[`j',`j']=1			// will test slope of model 1 for reference. 

	matrix rt=R[`j',1..27]
	matrix tbot=cholesky((rt*omega*rt')*inv(tterm))

	matrix rb=rt*b

	matrix t`j'=rb*inv(tbot)

	matrix fbot=syminv(R*omega*R')

	matrix F`j'=tterm*(R*b)'*fbot*(R*b)
	display "t"`j' " = " t`j'[1,1] "    F"`j' " = " F`j'[1,1]

			}



*			Test Average Model Slope = Average Obs Slope
matrix R=I(26)-I(26)			// start by making R as a 26x26 matrix of zeros 
matrix R26=J(26,1,0)			// make 26x1-length vector of zeros
matrix R=R,R26				// append it to side of R, making R now 26x27

*			Generate weights to test if ensemble means=obs means
*matrix R1=(1,5,1,1,1,1,1,1,2,6,5,3,1,1,1,1,3,5,4,7,4,1,1)
matrix R1=(1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1)
matrix R1=(1/23)*R1
matrix R1R=(-0.25,-0.25,-0.25,-0.25)
matrix R1=R1,R1R				// R1 is now 1x27 vector of testing weights
matrix R=R1\R				// make it top row of R, now R is 27x27

*		Construct F stat
	matrix fbot=syminv(R*omega*R')
	matrix F=tterm*(R*b)'*fbot*(R*b)
	matrix list F







*			Test UAH Slope = RSS Slope

matrix R=I(26)-I(26)			// start by making R as a 27x27 matrix of zeros 
matrix R26=J(26,1,0)			// make 26x1-length vector of zeros
matrix R=R,R26				// append it to side of R, making R now 26x27

*			Generate test weights 
matrix R1=(0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,-1,0,0)	
matrix R=R1\R				// make it top row of R, now R is 27x27

*		Construct F stat
	matrix fbot=syminv(R*omega*R')
	matrix F=tterm*(R*b)'*fbot*(R*b)
	matrix list F


*			Test MSU Slope = balloon Slope

matrix R=I(26)-I(26)			// start by making R as a 27x27 matrix of zeros 
matrix R26=J(26,1,0)			// make 26x1-length vector of zeros
matrix R=R,R26				// append it to side of R, making R now 26x27

*			Generate test weights 
matrix R1=(0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,.5,.5,-.5,-.5)	
matrix R=R1\R				// make it top row of R, now R is 27x27

	matrix fbot=syminv(R*omega*R')

	matrix F=tterm*(R*b)'*fbot*(R*b)
	matrix list F


*			Test Joint Obs Slope Significance

matrix R=I(26)-I(26)			// start by making R as a 27x27 matrix of zeros 
matrix R26=J(26,1,0)			// make 26x1-length vector of zeros
matrix R=R,R26				// append it to side of R, making R now 26x27

*			Generate test weights 
matrix R1=(0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,.25,.25,.25,.25)	
matrix R=R1\R				// make it top row of R, now R is 27x27

	matrix fbot=syminv(R*omega*R')

	matrix F=tterm*(R*b)'*fbot*(R*b)
	matrix list F


exit

